@@ -5,7 +5,7 @@
 # tenant.py
 # Classes dealing directly with OpsRamp Tenants.
 #
-# (c) Copyright 2019-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,29 +19,31 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 from opsramp.api import ORapi
-import opsramp.rba
+import opsramp.devmgmt
+import opsramp.escalations
+import opsramp.first_response
+import opsramp.integrations
+import opsramp.kb
+import opsramp.mgmt_profiles
 import opsramp.monitoring
 import opsramp.msp
-import opsramp.devmgmt
-import opsramp.integrations
-import opsramp.roles
-import opsramp.escalations
-import opsramp.mgmt_profiles
-import opsramp.sites
-import opsramp.service_maps
-import opsramp.kb
+import opsramp.rba
+import opsramp.resource_groups
 import opsramp.resources
-import opsramp.first_response
+import opsramp.roles
+import opsramp.service_maps
+import opsramp.sites
 
 
 class Tenant(ORapi):
     def __init__(self, parent, uuid):
-        super(Tenant, self).__init__(parent.api, 'tenants/%s' % uuid)
+        super(Tenant, self).__init__(parent.api, "tenants/%s" % uuid)
         self.uuid = uuid
 
     def is_client(self):
-        return self.uuid[:7] == 'client_'
+        return self.uuid[:7] == "client_"
 
     def rba(self):
         return opsramp.rba.Rba(self)
@@ -64,8 +66,8 @@ class Tenant(ORapi):
 
     def get_agent_script(self):
         assert self.is_client()
-        hdr = {'Accept': 'application/octet-stream,application/xml'}
-        return self.api.get('agents/deployAgentsScript', headers=hdr)
+        hdr = {"Accept": "application/octet-stream,application/xml"}
+        return self.api.get("agents/deployAgentsScript", headers=hdr)
 
     def credential_sets(self):
         return opsramp.devmgmt.CredentialSets(self)
@@ -99,3 +101,6 @@ class Tenant(ORapi):
 
     def model_training(self):
         return opsramp.first_response.ModelTraining(self)
+
+    def resource_groups(self):
+        return opsramp.resource_groups.ResourceGroups(self)
