@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2020-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2020-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,27 +16,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
-import yaml
-import logging
 import argparse
+import logging
+import os
 
 import opsramp.binding
+import yaml
 
 
 def connect():
-    url = os.environ['OPSRAMP_URL']
-    key = os.environ['OPSRAMP_KEY']
-    secret = os.environ['OPSRAMP_SECRET']
+    url = os.environ["OPSRAMP_URL"]
+    key = os.environ["OPSRAMP_KEY"]
+    secret = os.environ["OPSRAMP_SECRET"]
     return opsramp.binding.connect(url, key, secret)
 
 
 def parse_argv():
     parser = argparse.ArgumentParser()
-    parser.add_argument(
-        '-d', '--debug',
-        action='store_true'
-    )
+    parser.add_argument("-d", "--debug", action="store_true")
     ns = parser.parse_args()
     return ns
 
@@ -47,7 +44,7 @@ def main():
         logging.basicConfig()
         logging.getLogger().setLevel(logging.DEBUG)
 
-    tenant_id = os.environ['OPSRAMP_TENANT_ID']
+    tenant_id = os.environ["OPSRAMP_TENANT_ID"]
 
     ormp = connect()
     tenant = ormp.tenant(tenant_id)
@@ -57,13 +54,14 @@ def main():
         "filterCriteria": {
             "filterBased": "true",
             "matchingType": "ALL",
-            "rules": [{
-                "filterType": "native",
-                "entityName": "host_name",
-                "operator": "Starts With",
-                "entityValue": "value_of_attribute"
-            }
-            ]
+            "rules": [
+                {
+                    "filterType": "native",
+                    "entityName": "host_name",
+                    "operator": "Starts With",
+                    "entityValue": "value_of_attribute",
+                }
+            ],
         },
         "firstResponseType": "SUPPRESSION",
         "suppression": {
@@ -71,8 +69,8 @@ def main():
             "suppressByAttributes": "true",
             "autoSnooze": "true",
             "continuousLearning": "true",
-            "trainingFileId": "ml_alert_first_response_training"
-        }
+            "trainingFileId": "ml_alert_first_response_training",
+        },
     }
     frpolicies = tenant.first_response()
     resp = frpolicies.create(jdata)
