@@ -2,7 +2,7 @@
 #
 # Exercise the opsramp module as an illustration of how to use it.
 #
-# (c) Copyright 2019 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,30 +16,43 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
+import argparse
+import logging
 import os
-import yaml
 
 import opsramp.binding
+import yaml
 
 
 def connect():
-    url = os.environ['OPSRAMP_URL']
-    key = os.environ['OPSRAMP_KEY']
-    secret = os.environ['OPSRAMP_SECRET']
+    url = os.environ["OPSRAMP_URL"]
+    key = os.environ["OPSRAMP_KEY"]
+    secret = os.environ["OPSRAMP_SECRET"]
     return opsramp.binding.connect(url, key, secret)
 
 
+def parse_argv():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("-d", "--debug", action="store_true")
+    ns = parser.parse_args()
+    return ns
+
+
 def main():
-    tenant_id = os.environ['OPSRAMP_TENANT_ID']
+    ns = parse_argv()
+    if ns.debug:
+        logging.basicConfig()
+        logging.getLogger().setLevel(logging.DEBUG)
+
+    tenant_id = os.environ["OPSRAMP_TENANT_ID"]
 
     ormp = connect()
     tenant = ormp.tenant(tenant_id)
     group = tenant.roles()
 
     found = group.search()
-    print(found['totalResults'], 'roles found in tenant', tenant_id)
-    print(yaml.dump(found['results'], default_flow_style=False))
+    print(found["totalResults"], "roles found in tenant", tenant_id)
+    print(yaml.dump(found["results"], default_flow_style=False))
 
 
 if __name__ == "__main__":
