@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# (c) Copyright 2019-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,45 +15,41 @@
 # limitations under the License.
 
 import unittest
-import requests_mock
 
 import opsramp.binding
+import requests_mock
 
 
 class BindingTest(unittest.TestCase):
     def setUp(self):
-        endpoint = 'mock://api.example.com'
-        key = 'opensesame'
-        secret = 'thereisnospoon'
-        token = 'fake-unit-test-token'
+        endpoint = "mock://api.example.com"
+        key = "opensesame"
+        secret = "thereisnospoon"
+        token = "fake-unit-test-token"
 
-        url = endpoint + '/auth/oauth/token'
-        hshake = 'grant_type=client_credentials&client_id=%s&client_secret=%s'
+        url = endpoint + "/auth/oauth/token"
+        hshake = "grant_type=client_credentials&client_id=%s&client_secret=%s"
         expected_send = hshake % (key, secret)
-        expected_receive = {'access_token': token}
+        expected_receive = {"access_token": token}
         expected_auth = {
-            'Authorization': 'Bearer ' + token,
-            'Accept': 'application/json,application/xml'
+            "Authorization": "Bearer " + token,
+            "Accept": "application/json,application/xml",
         }
         with requests_mock.Mocker() as m:
             adapter = m.post(url, json=expected_receive, complete_qs=True)
-            self.ormp = opsramp.binding.connect(
-                endpoint,
-                key,
-                secret
-            )
+            self.ormp = opsramp.binding.connect(endpoint, key, secret)
             assert m.call_count == 1
             assert adapter.last_request.text == expected_send
             assert type(self.ormp) is opsramp.binding.Opsramp
             assert self.ormp.auth == expected_auth
 
     def test_str(self):
-        assert 'Opsramp' in str(self.ormp)
+        assert "Opsramp" in str(self.ormp)
 
     def test_config(self):
         obj = self.ormp.config()
-        assert 'GlobalConfig' in str(obj)
+        assert "GlobalConfig" in str(obj)
 
     def test_tenant(self):
-        obj = self.ormp.tenant('unit-test')
-        assert 'Tenant' in str(obj)
+        obj = self.ormp.tenant("unit-test")
+        assert "Tenant" in str(obj)
