@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# (c) Copyright 2019-2021 Hewlett Packard Enterprise Development LP
+# (c) Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,39 +15,39 @@
 # limitations under the License.
 
 import unittest
-import requests_mock
 
 import opsramp.binding
+import requests_mock
 
 
 class ApiTest(unittest.TestCase):
     def setUp(self):
-        fake_url = 'mock://api.example.com'
-        fake_token = 'unit-test-fake-token'
+        fake_url = "mock://api.example.com"
+        fake_token = "unit-test-fake-token"
         self.ormp = opsramp.binding.Opsramp(fake_url, fake_token)
 
-        self.fake_client_id = 'client_for_unit_test'
+        self.fake_client_id = "client_for_unit_test"
         self.client = self.ormp.tenant(self.fake_client_id)
         assert self.client.is_client()
 
         self.sites = self.client.sites()
-        assert 'Sites' in str(self.sites)
+        assert "Sites" in str(self.sites)
 
     def test_site_search(self):
         group = self.sites
         thisid = 123456
-        expected = {'id': thisid}
-        pattern = 'whatever'
+        expected = {"id": thisid}
+        pattern = "whatever"
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('search?%s' % pattern)
+            url = group.api.compute_url("search?%s" % pattern)
             m.get(url, json=expected, complete_qs=True)
             actual = group.search(pattern)
             assert actual == expected
 
     def test_site_create(self):
         group = self.sites
-        expected = {'id': 345678}
-        fake_defn = {'name': 'fr cyril mcduff'}
+        expected = {"id": 345678}
+        fake_defn = {"name": "fr cyril mcduff"}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url()
             m.post(url, json=expected, complete_qs=True)
@@ -57,8 +57,8 @@ class ApiTest(unittest.TestCase):
     def test_site_update(self):
         group = self.sites
         thisid = 123456
-        expected = {'id': thisid}
-        fake_defn = {'name': 'fr cyril mcduff'}
+        expected = {"id": thisid}
+        fake_defn = {"name": "fr cyril mcduff"}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url(thisid)
             m.post(url, json=expected, complete_qs=True)
@@ -68,7 +68,7 @@ class ApiTest(unittest.TestCase):
     def test_site_delete(self):
         group = self.sites
         thisid = 789012
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url(thisid)
             m.delete(url, json=expected, complete_qs=True)
@@ -78,7 +78,7 @@ class ApiTest(unittest.TestCase):
     def test_site_get_id(self):
         group = self.sites
         thisid = 345678
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
             url = group.api.compute_url(thisid)
             m.get(url, json=expected, complete_qs=True)
@@ -88,13 +88,13 @@ class ApiTest(unittest.TestCase):
     def test_site_get_list(self):
         group = self.sites
         thisid = 901234
-        expected = {'id': thisid}
+        expected = {"id": thisid}
         with requests_mock.Mocker() as m:
-            url = group.api.compute_url('minimal')
+            url = group.api.compute_url("minimal")
             m.get(url, json=expected, complete_qs=True)
             # default suffix should be "minimal"
             actual = group.get()
             assert actual == expected
             # specific suffix
-            actual = group.get('minimal')
+            actual = group.get("minimal")
             assert actual == expected
